@@ -1,10 +1,10 @@
-// Copyright (c) 2016 University of Helsinki                          
-//                                                                    
-// This library is free software; you can redistribute it and/or      
-// modify it under the terms of the GNU Lesser General Public         
-// License as published by the Free Software Foundation; either       
+// Copyright (c) 2016 University of Helsinki
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
 // version 3 of the License, or (at your option) any later version.
-// See the file COPYING included with this distribution for more      
+// See the file COPYING included with this distribution for more
 // information.
 
 #if HAVE_CONFIG_H
@@ -15,8 +15,8 @@
 
 #include "ConvertTransducerFormat.h"
 #include "optimized-lookup/convert.h"
-#include "HfstTransitionGraph.h"
-#include "HfstTransducer.h"
+#include "HfstBasicTransducer.h"
+//#include "HfstTransducer.h"
 
 #ifndef MAIN_TEST
 namespace hfst { namespace implementations
@@ -24,14 +24,14 @@ namespace hfst { namespace implementations
 
   /* -----------------------------------------------------------
 
-      Conversion functions between HfstBasicTransducer and 
-      optimized lookup transducers 
+      Conversion functions between HfstBasicTransducer and
+      optimized lookup transducers
 
       ---------------------------------------------------------- */
 
 /* An auxiliary function. */
 unsigned int hfst_ol_to_hfst_basic_add_state
-(hfst_ol::Transducer * t, 
+(hfst_ol::Transducer * t,
  HfstBasicTransducer * basic,
  hfst_ol::HfstOlToBasicStateMap & state_map,
  bool weighted,
@@ -50,9 +50,10 @@ unsigned int hfst_ol_to_hfst_basic_add_state
         basic->add_state(new_state);
         basic->set_final_weight(new_state,
                                 weighted ?
-                                dynamic_cast<const hfst_ol::TransitionWIndex&>
-                                (transition_index).final_weight() :
-                                0.0);
+                                hfst::double_to_float
+                                (dynamic_cast<const hfst_ol::TransitionWIndex&>
+                                 (transition_index).final_weight()) :
+                                (float)0.0);
     }
   }
   else // indexes transition table
@@ -64,9 +65,10 @@ unsigned int hfst_ol_to_hfst_basic_add_state
         basic->add_state(new_state);
         basic->set_final_weight(new_state,
                                 weighted ?
-                                dynamic_cast<const hfst_ol::TransitionW&>
-                                (transition).get_weight() :
-                                0.0);
+                                hfst::double_to_float
+                                (dynamic_cast<const hfst_ol::TransitionW&>
+                                 (transition).get_weight()) :
+                                (float)0.0);
     }
   }
   return new_state;
@@ -79,15 +81,15 @@ unsigned int hfst_ol_to_hfst_basic_add_state
   {
       HfstBasicTransducer * basic = new HfstBasicTransducer();
       bool weighted = t->get_header().probe_flag(hfst_ol::Weighted);
-      const hfst_ol::SymbolTable& symbols 
+      const hfst_ol::SymbolTable& symbols
         = t->get_alphabet().get_symbol_table();
       
       
-      /* This contains indices to either (1) the start of a set of entries 
-         in the transition index table, or (2) the boundary before a set 
-         of entries in the transition table; in this case, the following 
-         entries will all have the same input symbol. In either case 
-         the index represents a state and may be final The will already be 
+      /* This contains indices to either (1) the start of a set of entries
+         in the transition index table, or (2) the boundary before a set
+         of entries in the transition table; in this case, the following
+         entries will all have the same input symbol. In either case
+         the index represents a state and may be final The will already be
          an entry in state_map for each value in agenda */
       std::vector<hfst_ol::TransitionTableIndex> agenda;
       hfst_ol::HfstOlToBasicStateMap state_map;
@@ -103,7 +105,7 @@ unsigned int hfst_ol_to_hfst_basic_add_state
           
           unsigned int current_state = state_map[current_index];
           
-          hfst_ol::TransitionTableIndexSet transitions 
+          hfst_ol::TransitionTableIndexSet transitions
             = t->get_transitions_from_state(current_index);
           for(hfst_ol::TransitionTableIndexSet::const_iterator it
                 =transitions.begin();it!=transitions.end();it++)
@@ -114,7 +116,7 @@ unsigned int hfst_ol_to_hfst_basic_add_state
               {
                   state_number++;
                   hfst_ol_to_hfst_basic_add_state
-                    (t, basic, state_map, weighted, 
+                    (t, basic, state_map, weighted,
                      transition.get_target(), state_number);
                   agenda.push_back(transition.get_target());
               }
@@ -170,11 +172,11 @@ void get_states_and_symbols(
     
     unsigned int first_transition = 0;
     unsigned int state_number = 0;
-    for (HfstBasicTransducer::const_iterator it = t->begin(); 
+    for (HfstBasicTransducer::const_iterator it = t->begin();
          it != t->end(); ++it) {
         hfst_ol::Weight final_w = 0.0;
         if (t->is_final_state(state_number)) {
-            final_w = t->get_final_weight(state_number);    
+            final_w = t->get_final_weight(state_number);
         }
         state_placeholders.push_back(hfst_ol::StatePlaceholder(
                                          state_number,
@@ -182,7 +184,7 @@ void get_states_and_symbols(
                                          first_transition,
                                          final_w));
         ++first_transition; // there's a padding entry between states
-        for (HfstBasicTransducer::HfstTransitions::const_iterator tr_it 
+        for (HfstBasicTransitions::const_iterator tr_it
                  = it->begin();
              tr_it != it->end(); ++tr_it) {
             ++first_transition;
@@ -207,14 +209,14 @@ void get_states_and_symbols(
     if (harmonizer == NULL) {
         
         // 1) epsilon
-        string_symbol_map[internal_epsilon] = symbol_table.size();
+        string_symbol_map[internal_epsilon] = hfst::size_t_to_ushort(symbol_table.size());
         symbol_table.push_back(internal_epsilon);
         
         // 2) input symbols
         for (std::set<std::string>::iterator it = input_symbols->begin();
              it != input_symbols->end(); ++it) {
             if (!is_epsilon(*it)) {
-                string_symbol_map[*it] = symbol_table.size();
+                string_symbol_map[*it] = hfst::size_t_to_ushort(symbol_table.size());
                 symbol_table.push_back(*it);
                 ++seen_input_symbols;
             }
@@ -224,7 +226,7 @@ void get_states_and_symbols(
         for (std::set<std::string>::iterator it = flag_diacritics->begin();
              it != flag_diacritics->end(); ++it) {
             if (!is_epsilon(*it)) {
-                string_symbol_map[*it] = symbol_table.size();
+                string_symbol_map[*it] = hfst::size_t_to_ushort(symbol_table.size());
                 // TODO: cl.exe: conversion from 'size_t' to 'char16_t'
                 flag_symbols.insert((unsigned short)symbol_table.size());
                 symbol_table.push_back(*it);
@@ -238,7 +240,7 @@ void get_states_and_symbols(
              it != other_symbols->end(); ++it) {
             if (!is_epsilon(*it) && input_symbols->count(*it) == 0 &&
               flag_diacritics->count(*it) == 0) {
-                string_symbol_map[*it] = symbol_table.size();
+                string_symbol_map[*it] = hfst::size_t_to_ushort(symbol_table.size());
                 symbol_table.push_back(*it);
             }
         }
@@ -262,9 +264,9 @@ void get_states_and_symbols(
     // about the states except starting indices
 
     state_number = 0;
-    for (HfstBasicTransducer::const_iterator it = t->begin(); 
+    for (HfstBasicTransducer::const_iterator it = t->begin();
          it != t->end(); ++it) {
-        for (HfstBasicTransducer::HfstTransitions::const_iterator tr_it 
+        for (HfstBasicTransitions::const_iterator tr_it
                = it->begin();
              tr_it != it->end(); ++tr_it) {
             // add input in case we're seeing it the first time
@@ -277,7 +279,7 @@ void get_states_and_symbols(
                 string_symbol_map[tr_it->get_input_symbol()],
                 string_symbol_map[tr_it->get_output_symbol()],
                 tr_it->get_weight());
-            SymbolNumber input_sym = string_symbol_map[tr_it->get_input_symbol()];
+            //SymbolNumber input_sym = string_symbol_map[tr_it->get_input_symbol()];
             state_placeholders[state_number].add_transition(trans);
         }
         ++state_number;
@@ -291,9 +293,9 @@ void get_states_and_symbols(
   (const HfstBasicTransducer * t, bool weighted, std::string options,
    HfstTransducer * harmonizer)
   {
-      const float packing_aggression = 0.85;
+      const float packing_aggression = (float)0.85; // double -> const float
       const int floor_jump_threshold = 4; // a packing aggression parameter
-      bool quick = options == "quick";
+      //bool quick = options == "quick";
       // The transition array is indexed starting from this constant
       const unsigned int TA_OFFSET = 2147483648u;
 
@@ -396,7 +398,7 @@ void get_states_and_symbols(
     
     unsigned int greatest_index = 0;
     if (used_indices->indices.size() != 0) {
-        greatest_index = used_indices->indices.size() - 1;
+        greatest_index = hfst::size_t_to_uint(used_indices->indices.size() - 1);
     }
 
     for(unsigned int i = 0; i <= greatest_index; ++i) {
@@ -441,7 +443,7 @@ void get_states_and_symbols(
 
     hfst_ol::TransducerAlphabet alphabet(symbol_table);
     hfst_ol::TransducerHeader header(seen_input_symbols,
-                                     symbol_table.size(),
+                                     hfst::size_t_to_ushort(symbol_table.size()),
                                      windex_table.size(),
                                      wtransition_table.size(),
                                      weighted);
