@@ -279,6 +279,48 @@ namespace hfst {
     t->SetInputSymbols(&st);
   }
 
+  void TropicalWeightTransducer::get_initial_input_symbols
+  (StdVectorFst *t, StateId s, std::set<StateId> & visited_states, StringSet & symbols)
+  {
+    visited_states.insert(s);
+    for (fst::ArcIterator<StdVectorFst> aiter(*t,s);
+         !aiter.Done(); aiter.Next())
+      {
+        const StdArc &arc = aiter.Value();
+        assert(t->InputSymbols() != NULL);
+        std::string sym = t->InputSymbols()->Find(arc.ilabel);
+        assert(sym != "");
+
+        if ((!FdOperation::is_diacritic(sym)) && arc.ilabel != 0 )
+          {
+            symbols.insert(sym);
+          }
+	else
+        {
+	    if (visited_states.find(arc.nextstate) == visited_states.end())
+            {
+		get_initial_input_symbols(t, arc.nextstate, visited_states, symbols);
+            }
+        }
+      }
+  }
+  
+  StringSet TropicalWeightTransducer::get_initial_input_symbols(StdVectorFst *t)
+  {
+    assert(t->InputSymbols() != NULL);
+    StringSet symbols;
+    StateId s = t->Start();
+    if (s + 1 == 0) {
+        // This can apparently happen with empty transducers
+        // causing a segfault
+        return symbols;
+    }
+    std::set<StateId> visited_states;
+    get_initial_input_symbols(t, s, visited_states, symbols);
+    return symbols;
+  }
+
+    // ???
   void TropicalWeightTransducer::get_first_input_symbols
   (StdVectorFst *t, StateId s, std::set<StateId> & visited_states, StringSet & symbols)
   {
@@ -302,6 +344,7 @@ namespace hfst {
       }
   }
 
+    // ???
   StringSet TropicalWeightTransducer::get_first_input_symbols(StdVectorFst *t)
   {
     assert(t->InputSymbols() != NULL);
