@@ -13,6 +13,7 @@
 #include <sstream>
 #include "applicators.h"
 #include "lookup-state.h"
+#include "lookup-path.h"
 #include "formatter.h"
 
 //////////Function definitions for TokenizationApplicator
@@ -31,8 +32,8 @@ TokenizationApplicator::process_token(const Token& t) const
     s << "Reserved char: '" << t.character << "'";
   else if(t.type == None)
     s << "None/EOF";
-  
-  s << " (to_symbol: " << token_stream.to_symbol(t) << ")" 
+
+  s << " (to_symbol: " << token_stream.to_symbol(t) << ")"
     << " (alphabetic: " << token_stream.is_alphabetic(t) << ")";
   if(t.type == Symbol)
   {
@@ -84,7 +85,7 @@ AnalysisApplicator::apply()
   size_t last_stream_location = 0;
   TokenVector surface_form;
   ProcResult analyzed_forms;
-  
+
   Token next_token;
   while((next_token = token_stream.get_token()).type != None)
   {
@@ -101,13 +102,13 @@ AnalysisApplicator::apply()
     }
     if(next_token.type == ReservedCharacter)
       stream_error(std::string("Found unexpected character ")+next_token.character+" unescaped in stream");
-    
+
         if(surface_form.size() > 0 && state.is_final())
         {
           LookupPathSet finals = state.get_finals_set();
       if (caps_mode == DictionaryCase || caps_mode == CaseSensitiveDictionaryCase)
         {
-              analyzed_forms = formatter.process_finals(finals, 
+              analyzed_forms = formatter.process_finals(finals,
                                                         Unknown);
         }
       else
@@ -116,16 +117,16 @@ AnalysisApplicator::apply()
                                                                                 token_stream.get_capitalization_state(surface_form));
         }
           last_stream_location = token_stream.get_pos()-1;
-          
+
           if(printDebuggingInformationFlag)
             std::cout << "Final paths (" << finals.size() << ") found and saved, stream location is " << last_stream_location << std::endl;
         }
-        
+
         state.step(token_stream.to_symbol(next_token), caps_mode);
-    
+
     if(printDebuggingInformationFlag)
       std::cout << "After stepping, there are " << state.num_active() << " active paths" << std::endl;
-    
+
     if(state.is_active())
     {
       surface_form.push_back(next_token);
@@ -137,7 +138,7 @@ AnalysisApplicator::apply()
         if(formatter.preserve_nonalphabetic())
           token_stream << next_token;
       }
-      else if(analyzed_forms.size() == 0 || 
+      else if(analyzed_forms.size() == 0 ||
               (token_stream.is_alphabetic(token_stream.at(last_stream_location)) &&
                token_stream.is_alphabetic(surface_form[surface_form.size()-1])))
       {
@@ -155,7 +156,7 @@ AnalysisApplicator::apply()
           // we overstepped the word by one token
           token_stream.move_back(1);
         }
-        
+
         if(!token_stream.is_alphabetic(surface_form[0]))
         {
           if(formatter.preserve_nonalphabetic())
@@ -167,14 +168,14 @@ AnalysisApplicator::apply()
           //size_t word_length = token_stream.first_nonalphabetic(surface_form);
           //if(word_length == string::npos)
           size_t word_length = surface_form.size();
-          
-          int revert_count = surface_form.size()-word_length+
-                         next_token_is_part_of_word ? 0 : 1;
-          
+
+          int revert_count = (surface_form.size()-word_length+
+                              next_token_is_part_of_word) ? 0 : 1;
+
           if(printDebuggingInformationFlag)
-            std::cout << "word_length=" << word_length << ", surface_form.size()=" << surface_form.size() 
+            std::cout << "word_length=" << word_length << ", surface_form.size()=" << surface_form.size()
                       << ", moving back " << revert_count << " characters" << std::endl;
-          
+
           formatter.print_unknown_word(TokenVector(surface_form.begin(),
                                                 surface_form.begin()+word_length));
           token_stream.move_back(revert_count);
@@ -185,21 +186,21 @@ AnalysisApplicator::apply()
         // the number of symbols on the end of surface_form that aren't a part
         // of the transduction(s) found
         int revert_count = token_stream.diff_prev(last_stream_location+1);
-        formatter.print_word(TokenVector(surface_form.begin(), 
+        formatter.print_word(TokenVector(surface_form.begin(),
                                                 surface_form.end()-revert_count),
-                                   analyzed_forms); 
+                                   analyzed_forms);
         token_stream.move_back(revert_count+1);
       }
-      
+
       state.reset();
       surface_form.clear();
       analyzed_forms.clear();
     }
   }
-  
+
   if(verboseFlag)
     std::cout << std::endl << "Got None/EOF symbol; done." << std::endl;
-  
+
   // print any valid transductions stored
   if(analyzed_forms.size() != 0)// && token_stream.get_pos() == last_stream_location)
     formatter.print_word(surface_form, analyzed_forms);
@@ -237,16 +238,16 @@ GenerationApplicator::apply()
           else
             form.push_back(next_token);
         }
-        
+
         //Figure out how to output the word
-        
+
         if(prefix_char == '*' || prefix_char == '@') // the word is unanalyzed (*) or untranslated (@)
         {
           if(mode != gm_clean)
             token_stream.write_escaped(std::string(1,prefix_char));
-          
+
           std::string word = token_stream.read_delimited('$');
-          
+
           if(prefix_char == '*' || (prefix_char == '@' && mode != gm_all))
           {
             size_t loc = word.find('<');
@@ -262,7 +263,7 @@ GenerationApplicator::apply()
         else
         {
           // first try unsplit
-          
+
           if(!lookup(form, false))
             {
               std::vector<TokenVector> parts = split(form);
@@ -272,7 +273,7 @@ GenerationApplicator::apply()
                   lookup(*it, true);
                 }
             }
-          
+
           if(prefix_char == '#') // if there is an invariant part remaining
           {
             std::string invariant = token_stream.read_delimited('$');
@@ -307,10 +308,58 @@ GenerationApplicator::split(const TokenVector& tokens) const
   }
   if(start != tokens.end())
     res.push_back(TokenVector(start, tokens.end()));
-  
+
   return res;
 }
 
+
+LookupPathSet
+GenerationApplicator::preprocess_finals(const LookupPathSet& finals) const
+{
+  LookupPathSet goodcmp_finals(LookupPathW::compare_weights);
+  // insertion sort :)
+  for (LookupPathSet::const_iterator it = finals.begin(); it != finals.end(); ++it)
+  {
+      goodcmp_finals.insert(*it);
+  }
+  
+  // Keep only the N best weight classes
+  int classes_found = -1;
+  Weight last_weight_class = 0.0;
+  LookupPathSet goodweight_finals(LookupPathW::compare_weights); 
+  for(LookupPathSet::const_iterator it = goodcmp_finals.begin(); it != goodcmp_finals.end(); it++)
+  {
+          LookupPathW* pw = dynamic_cast<LookupPathW*>(*it);
+    if(pw != NULL) {
+      Weight current_weight = pw->get_weight();
+      if (classes_found == -1) // we're just starting
+      {
+        classes_found = 1;
+        last_weight_class = current_weight;
+      }
+      else if (last_weight_class != current_weight) // we might want to ignore the rest due to weight classes
+      {
+        last_weight_class = current_weight;
+        ++classes_found;
+      }
+      if (classes_found > maxWeightClasses)
+      {
+        break;
+      }
+    }
+    goodweight_finals.insert(*it);
+  }
+  // Keep no more than maxAnalyses
+  LookupPathSet clipped_finals(LookupPathW::compare_weights);
+  LookupPathSet::const_iterator it = goodweight_finals.begin();
+  for(int i=0; i < maxAnalyses && it != goodweight_finals.end(); i++, it++)
+  {
+          clipped_finals.insert(*it);
+  }
+  return clipped_finals;
+}
+
+
 bool
 GenerationApplicator::lookup(const TokenVector& tokens, bool generate_on_fail)
 {
@@ -318,24 +367,31 @@ GenerationApplicator::lookup(const TokenVector& tokens, bool generate_on_fail)
   state.lookup(token_stream.to_symbols(tokens), caps_mode);
   if(state.is_final()) // generation succeeded
   {
-    CapitalizationState capitalization_state = 
-      caps_mode==DictionaryCase ?
-        Unknown :
-        token_stream.get_capitalization_state(TokenVector(tokens.begin(),tokens.size()>1?tokens.begin()+2:tokens.end()));
     LookupPathSet finals = state.get_finals_set();
-    
+    CapitalizationState caps_change = Unknown;
+    if(caps_mode!=DictionaryCase) {
+        CapitalizationState lm_caps_state = token_stream.get_capitalization_state((*finals.begin())->get_output_symbols());
+        CapitalizationState sf_caps_state = token_stream.get_capitalization_state(TokenVector(tokens.begin(),tokens.size()>1?tokens.begin()+2:tokens.end()));
+        if(sf_caps_state != lm_caps_state) {
+            // We *only* change capitalization if lm and sf caps state differs
+            caps_change = sf_caps_state;
+        }
+    }
+
     if(printDebuggingInformationFlag)
             std::cout << "Generated " << finals.size() << " forms" << std::endl;
-    
-    token_stream.put_symbols((*finals.begin())->get_output_symbols(),capitalization_state);
-    if(finals.size() > 1)
+
+    LookupPathSet new_finals = preprocess_finals(finals);
+
+    token_stream.put_symbols((*new_finals.begin())->get_output_symbols(),caps_change);
+    if(new_finals.size() > 1)
     {
-      LookupPathSet::const_iterator it=finals.begin();
+      LookupPathSet::const_iterator it=new_finals.begin();
       it++; // start from begin+1
-      for(;it!=finals.end();it++)
+      for(;it!=new_finals.end();it++)
       {
         token_stream.ostream() << '/';
-        token_stream.put_symbols((*it)->get_output_symbols(),capitalization_state);
+        token_stream.put_symbols((*it)->get_output_symbols(),caps_change);
       }
     }
     return true;
@@ -366,4 +422,3 @@ GenerationApplicator::lookup(const TokenVector& tokens, bool generate_on_fail)
     }
   return false;
 }
-
